==> flink-1.15.0-src.tgz: flink-1.15.0/flink-table/flink-table-runtime/src/test/java/org/apache/flink/table/runtime/typeutils/InternalTypeInfosTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.runtime.typeutils;

import org.apache.flink.api.common.typeinfo.TypeInformation;
import org.apache.flink.api.common.typeutils.TypeInformationTestBase;

/** Test for {@link StringDataTypeInfo}, {@link DecimalDataTypeInfo}. */
public class InternalTypeInfosTest extends TypeInformationTestBase<TypeInformation<?>> {

    @Override
    protected TypeInformation[] getTestData() {
        return new TypeInformation[] {
            StringDataTypeInfo.INSTANCE,
            new DecimalDataTypeInfo(5, 2),
            new TimestampDataTypeInfo(0),
            new TimestampDataTypeInfo(3),
            new TimestampDataTypeInfo(6),
            new TimestampDataTypeInfo(9)
        };
    }
}

==> flink-2.2.0-src.tgz: flink-2.2.0/flink-table/flink-table-runtime/src/test/java/org/apache/flink/table/runtime/typeutils/InternalTypeInfosTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.runtime.typeutils;

import org.apache.flink.api.common.typeinfo.TypeInformation;
import org.apache.flink.api.common.typeutils.TypeInformationTestBase;

/** Test for {@link StringDataTypeInfo}, {@link DecimalDataTypeInfo}. */
class InternalTypeInfosTest extends TypeInformationTestBase<TypeInformation<?>> {

    @Override
    protected TypeInformation[] getTestData() {
        return new TypeInformation[] {
            StringDataTypeInfo.INSTANCE,
            new DecimalDataTypeInfo(5, 2),
            new TimestampDataTypeInfo(0),
            new TimestampDataTypeInfo(3),
            new TimestampDataTypeInfo(6),
            new TimestampDataTypeInfo(9)
        };
    }
}
